==> instapage_cms_plugin-7.x-3.40.tar.gz: instapage_cms_plugin/core/README.md <==
Description
-----------
Join the thousands of users who have downloaded the Instapage plugin for WordPress to seamlessly publish landing pages as a natural extension of your WordPress blog or website. All you have to do is select the 'Push to WordPress' publishing option within Instapage when you're finished with your landing page.

Instapage is the most powerful landing page platform on the market. Ideal for teams and agencies, Instapage has everything you need to build fully customizable, on-brand landing pages.

**No other landing page builder offers this level of precision with full design freedom**

Every promotion deserves a great page. One that you’re confident is pixel-perfect, exquisitely composed, professional and polished, whether it’s in desktop or mobile form. Our fully customizable builder is intuitive and powerful, so it’s easy to create on-brand, conversion-friendly landing pages.

Design without bounds by selecting from over 5,000 fonts and 33,000,000 images to work with. And, our new alignment, distribution and grouping features, ensure your work is perfect in desktop or mobile versions.

**Over 100+ Landing Page Templates to Get You Started**

**Save valuable time and money with our integrations**

Integrate with the most widely used marketing services, like Salesforce, Zapier, Drupal, Autopilot, MailChimp, Google Analytics, AWeber, GoToWebinar, to name just a few.

**Highest ranked support in the industry**

Join 250,000+ businesses who rely on Instapage.

Installation
------------
**Instapage WordPress Plugin Instructions:**
 1. When publishing your landing page from Instapage, choose WordPress.
 2. Go to Plugins in your WordPress administration, click Add New, and search for “Instapage WordPress Plugin”.
 3. Now click at Install Now button.
 4. Click on Activate after upload has completed.
 5. Go to Settings and choose Instapage.
 6. Log into your Instapage account.
 7. Now you can Add a New Page.
 8. Select a Page from the dropdown that you want to create a URL for (only pages published to WordPress are available).
 9. Create a URL, hit publish, and you're ready to promote your landing page!

Features
--------

- 100+ fully customizable and optimized templates all designed to increase conversions
- Designer-friendly builder
- Fully mobile responsive landing pages
- 5000+ Customizable Fonts (Google and Typekit)
- Custom domains
- Unlimited domains
- Enterprise Level Infrastructure & Support

Integrations
------------

- ActiveCampaign
- Autopilot
- AWeber
- Campaign Monitor
- Constant Contact
- Drupal
- E-goi
- Facebook
- Get Response
- Google Analytics
- GoToWebinar
- Infusionsoft
- Kissmetrics
- Mad Mimi
- SalesForce
- Webhooks
- WordPress
- Zapier
- Zoho CRM

Changelog
---------
= 3.1.9 (2017-07-13) =
- Fixed a bug with wrong variation serving
- Fixed Drupal JS and CSS aggregation problem

= 3.1.8 (2017-05-31) =
- Updated 'Tested up to' field
- Sending additional request headers to prevent caching
- Alternative method of passing Host parameter added
- Additional warning in diagnostic mode

= 3.1.7 (2017-05-09) =
- Fixed slug validator issue
- Installation improvement
- Fixed inaccurate status code issue
- Fixed problem with detection connected subaccount
- Fixed problem with email input error in login form

= 3.1.6 (2017-02-13) =
- Improved dynamic text replacement

= 3.1.4 (2017-02-01) =
- Fixed javascript errors on plugin's settings page
- Improved plugin installation
- Changed coding style

= 3.1.2 (2016-12-16) =
- Improved signing in into plugin

= 3.1.1 (2016-12-15) =
- Improved installation on Drupal
- Changed workflow for unpublish page via plugin
- Changed page fetching endpoint

= 3.1.0 (2016-11-28) =
- Improved compatibility with plugins use knockout.js
- Improved handling big requests
- Improved displaying 404 page header status
- Changed fetch landing pages

= 3.0.9 (2016-11-14) =
- Fixed problem with broken dashboard
- Fixed problem with not displayed page listing
- Improved auto-migration
- Improved stability

= 3.0.8 (2016-11-08) =
- Improved compatibility with other plugins
- Workaround for displaying plugin's link in sidebar
- Increased max length request limit

= 3.0.7 (2016-11-04) =
- Improved fetching big requests

= 3.0.6 (2016-11-03) =
- Improved slug detection method

= 3.0.5 (2016-11-03) =
- Improved fetching more than 50 pages
- Improved URL parsing
- Improved token validation
- Fixed publish link on dashboard

= 3.0.4 (2016-11-01) =
- unnecessary scripts removed from dashboard

= 3.0.3 (2016-11-01) =
- Compatibility with PHP >= 4.3
- Getting all pages ready for push
- Better parsing URL for homepage and 404 pages

= 3.0.2 (2016-10-31) =
- Cross origin proxy value fix

= 3.0.1 (2016-10-31) =
- PHP 5 compatibility fix
- DB Datetime fix

= 3.0 (2016-10-31) =
- Stable version.

==> instapage_cms_plugin-7.x-3.57.tar.gz: instapage_cms_plugin/core/README.md <==
Description
-----------
Join the thousands of users who have downloaded the Instapage plugin for WordPress to seamlessly publish landing pages as a natural extension of your WordPress blog or website. All you have to do is select the 'Push to WordPress' publishing option within Instapage when you're finished with your landing page.

Instapage is the most powerful landing page platform on the market. Ideal for teams and agencies, Instapage has everything you need to build fully customizable, on-brand landing pages.

**No other landing page builder offers this level of precision with full design freedom**

Every promotion deserves a great page. One that you’re confident is pixel-perfect, exquisitely composed, professional and polished, whether it’s in desktop or mobile form. Our fully customizable builder is intuitive and powerful, so it’s easy to create on-brand, conversion-friendly landing pages.

Design without bounds by selecting from over 5,000 fonts and 33,000,000 images to work with. And, our new alignment, distribution and grouping features, ensure your work is perfect in desktop or mobile versions.

**Over 100+ Landing Page Templates to Get You Started**

**Save valuable time and money with our integrations**

Integrate with the most widely used marketing services, like Salesforce, Zapier, Drupal, Autopilot, MailChimp, Google Analytics, AWeber, GoToWebinar, to name just a few.

**Highest ranked support in the industry**

Join 250,000+ businesses who rely on Instapage.

Installation
------------
**Instapage Plugin Instructions:**
1. When publishing your landing page from Instapage, choose WordPress.
2. Go to Plugins in your WordPress administration, click Add New, and search for “Instapage Plugin”.
3. Now click at Install Now button.
4. Click on Activate after upload has completed.
5. Go to Settings and choose Instapage.
6. Log into your Instapage account.
7. Now you can Add a New Page.
8. Select a Page from the dropdown that you want to create a URL for (only pages published to WordPress are available).
9. Create a URL, hit publish, and you're ready to promote your landing page!

Features
--------

- 100+ fully customizable and optimized templates all designed to increase conversions
- Designer-friendly builder
- Fully mobile responsive landing pages
- 5000+ Customizable Fonts (Google and Typekit)
- Custom domains
- Unlimited domains
- Enterprise Level Infrastructure & Support

Integrations
------------

- ActiveCampaign
- Autopilot
- AWeber
- Campaign Monitor
- Constant Contact
- Drupal
- E-goi
- Facebook
- Get Response
- Google Analytics
- GoToWebinar
- Infusionsoft
- Kissmetrics
- Mad Mimi
- SalesForce
- Webhooks
- WordPress
- Zapier
- Zoho CRM

Changelog
---------
= 3.1.9 (2017-07-13) =
- Fixed a bug with wrong variation serving
- Fixed Drupal JS and CSS aggregation problem

= 3.1.8 (2017-05-31) =
- Updated 'Tested up to' field
- Sending additional request headers to prevent caching
- Alternative method of passing Host parameter added
- Additional warning in diagnostic mode

= 3.1.7 (2017-05-09) =
- Fixed slug validator issue
- Installation improvement
- Fixed inaccurate status code issue
- Fixed problem with detection connected subaccount
- Fixed problem with email input error in login form

= 3.1.6 (2017-02-13) =
- Improved dynamic text replacement

= 3.1.4 (2017-02-01) =
- Fixed javascript errors on plugin's settings page
- Improved plugin installation
- Changed coding style

= 3.1.2 (2016-12-16) =
- Improved signing in into plugin

= 3.1.1 (2016-12-15) =
- Improved installation on Drupal
- Changed workflow for unpublish page via plugin
- Changed page fetching endpoint

= 3.1.0 (2016-11-28) =
- Improved compatibility with plugins use knockout.js
- Improved handling big requests
- Improved displaying 404 page header status
- Changed fetch landing pages

= 3.0.9 (2016-11-14) =
- Fixed problem with broken dashboard
- Fixed problem with not displayed page listing
- Improved auto-migration
- Improved stability

= 3.0.8 (2016-11-08) =
- Improved compatibility with other plugins
- Workaround for displaying plugin's link in sidebar
- Increased max length request limit

= 3.0.7 (2016-11-04) =
- Improved fetching big requests

= 3.0.6 (2016-11-03) =
- Improved slug detection method

= 3.0.5 (2016-11-03) =
- Improved fetching more than 50 pages
- Improved URL parsing
- Improved token validation
- Fixed publish link on dashboard

= 3.0.4 (2016-11-01) =
- unnecessary scripts removed from dashboard

= 3.0.3 (2016-11-01) =
- Compatibility with PHP >= 4.3
- Getting all pages ready for push
- Better parsing URL for homepage and 404 pages

= 3.0.2 (2016-10-31) =
- Cross origin proxy value fix

= 3.0.1 (2016-10-31) =
- PHP 5 compatibility fix
- DB Datetime fix

= 3.0 (2016-10-31) =
- Stable version.
